==> moodle_1.3.1.orig.tar.gz: moodle/lang/fi/countries.php <==
<?PHP // $Id: countries.php,v 1.6 2004/05/02 16:47:21 paca70 Exp $ 
      // countries.php - created with Moodle 1.3 development (2004050200)


$string['AD'] = 'Andorra';
$string['AE'] = 'Yhdistyneet arabi emiirikunnat';
$string['AF'] = 'Afganistan';
$string['AG'] = 'Antigua ja Barbuda';
$string['AI'] = 'Angola';
$string['AL'] = 'Albania';
$string['AM'] = 'Armenia';
$string['AN'] = 'Alankomaiden Antillit';
$string['AO'] = 'Angola';
$string['AQ'] = 'Antarktis';
$string['AR'] = 'Argentiina';
$string['AS'] = 'Amerikan Samoa';
$string['AT'] = 'Itvalta';
$string['AU'] = 'Austraalia';
$string['AW'] = 'Aruba';
$string['AZ'] = 'Azerbaidzan';
$string['BA'] = 'Bosnia-Herzegovina';
$string['BB'] = 'Barbados';
$string['BD'] = 'Bangladesh';
$string['BE'] = 'Belgia';
$string['BF'] = 'Burkina Faso';
$string['BG'] = 'Bulgaria';
$string['BH'] = 'Bahrain';
$string['BI'] = 'Burundi';
$string['BJ'] = 'Benin';
$string['BM'] = 'Bermuda';
$string['BN'] = 'Brunei';
$string['BO'] = 'Bolivia';
$string['BR'] = 'Brasilia';
$string['BS'] = 'Bahamasaaret';
$string['BT'] = 'Bhutan';
$string['BW'] = 'Botswana';
$string['BY'] = 'Valko-Venj';
$string['BZ'] = 'Belize';
$string['CA'] = 'Kanada';
$string['CC'] = 'Kookos-Saaret';
$string['CF'] = 'Keski-Afrikan tasavalta';
$string['CG'] = 'Kongo';
$string['CH'] = 'Sveitsi';
$string['CI'] = 'Norsunluurannikko';
$string['CL'] = 'Chile';
$string['CM'] = 'Kamerun';
$string['CN'] = 'Kiina';
$string['CO'] = 'Kolumbia';
$string['CR'] = 'Costa Rica';
$string['CS'] = 'Serbia ja Montenegro';
$string['CU'] = 'Kuuba';
$string['CV'] = 'Cap Verde';
$string['CX'] = 'Joulusaaret';
$string['CY'] = 'Kypros';
$string['CZ'] = 'Tsekki';
$string['DE'] = 'Saksa';
$string['DJ'] = 'Djibouti';
$string['DK'] = 'Tanska';
$string['DM'] = 'Dominica';
$string['DO'] = 'Dominikaaninen tasavalta';
$string['DZ'] = 'Algeria';
$string['EC'] = 'Ecuador';
$string['EE'] = 'Viro';
$string['EG'] = 'Egypti';
$string['EH'] = 'Lnsi-Sahara';
$string['ER'] = 'Eritrea';
$string['ES'] = 'Espanja';
$string['ET'] = 'Etiopia';
$string['FI'] = 'Suomi';
$string['FJ'] = 'Fiji';
$string['FK'] = 'Falkland-saaret';
$string['FM'] = 'Micronesian yhdistyneet kansakunnat';
$string['FO'] = 'Frsaaret';
$string['FR'] = 'Ranska';
$string['FX'] = 'Ranska; Metropolitan';
$string['GA'] = 'Gabon';
$string['GB'] = 'Iso-Britannia';
$string['GD'] = 'Grenada';
$string['GE'] = 'Georgia';
$string['GF'] = 'Ranskan Guayana';
$string['GH'] = 'Ghana';
$string['GI'] = 'Gibraltar';
$string['GL'] = 'Grnlanti';
$string['GM'] = 'Gambia';
$string['GN'] = 'Guinea';
$string['GP'] = 'Guadeloupe';
$string['GQ'] = 'Pivntasaajan Guinea';
$string['GR'] = 'Kreikka';
$string['GT'] = 'Guatemala';
$string['GU'] = 'Guam';
$string['GW'] = 'Guinea-Bissau';
$string['GY'] = 'Guayana';
$string['HK'] = 'Hong Kong';
$string['HN'] = 'Honduras';
$string['HR'] = 'Kroatia';
$string['HT'] = 'Haiti';
$string['HU'] = 'Unkari';
$string['ID'] = 'Indonesia';
$string['IE'] = 'Irlanti';
$string['IL'] = 'Israel';
$string['IN'] = 'Intia';
$string['IQ'] = 'Irak';
$string['IR'] = 'Iran';
$string['IS'] = 'Islanti';
$string['IT'] = 'Italia';
$string['JM'] = 'Jamaika';
$string['JO'] = 'Jordania';
$string['JP'] = 'Japani';
$string['KE'] = 'Kenia';
$string['KG'] = 'Kirgistan';
$string['KH'] = 'Kambodsa';
$string['KI'] = 'Kiribati';
$string['KM'] = 'Komorit';
$string['KO'] = 'Kosovo';
$string['KP'] = 'Pohjois-Korea';
$string['KR'] = 'Etel-Korea';
$string['KW'] = 'Kuwait';
$string['KY'] = 'Caymansaaret';
$string['KZ'] = 'Kazakstan';
$string['LB'] = 'Libanon';
$string['LC'] = 'Saint Lucia';
$string['LI'] = 'Liechtenstein';
$string['LK'] = 'Sri Lanka';
$string['LR'] = 'Liberia';
$string['LS'] = 'Lesoto';
$string['LT'] = 'Liettua';
$string['LU'] = 'Luxemburg';
$string['LV'] = 'Latvia';
$string['LY'] = 'Libya';
$string['MA'] = 'Marokko';
$string['MC'] = 'Monaco';
$string['MD'] = 'Moldova';
$string['MG'] = 'Madagaskar';
$string['MH'] = 'Marshalsaaret';
$string['MK'] = 'Makedonia';
$string['ML'] = 'Mali';
$string['MM'] = 'Myanmar';
$string['MN'] = 'Mongolia';
$string['MO'] = 'Macao';
$string['MQ'] = 'Martinique';
$string['MR'] = 'Mauritania';
$string['MS'] = 'Montserrat';
$string['MT'] = 'Malta';
$string['MU'] = 'Mauritius';
$string['MV'] = 'Malediivit';
$string['MW'] = 'Malawi';
$string['MX'] = 'Meksiko';
$string['MY'] = 'Malesia';
$string['MZ'] = 'Mosambik';
$string['NA'] = 'Namibia';
$string['NC'] = 'Uusi-Kaledonia';
$string['NE'] = 'Niger';
$string['NG'] = 'Nigeria';
$string['NI'] = 'Nikaragua';
$string['NL'] = 'Alankomaat';
$string['NO'] = 'Norja';
$string['NP'] = 'Nepal';
$string['NR'] = 'Nauru';
$string['NU'] = 'Niue';
$string['NZ'] = 'Uusi-Seelanti';
$string['OM'] = 'Oman';
$string['PA'] = 'Panama';
$string['PE'] = 'Peru';
$string['PF'] = 'Ranskan Polynesia';
$string['PG'] = 'Papua Uusi-Guinea';
$string['PH'] = 'Filippiinit';
$string['PK'] = 'Pakistan';
$string['PL'] = 'Puola';
$string['PN'] = 'Pitcairn';
$string['PR'] = 'Puerto Rico';
$string['PT'] = 'Portugali';
$string['PW'] = 'Palau';
$string['PY'] = 'Paraguay';
$string['QA'] = 'Qatar';
$string['RE'] = 'Reunion';
$string['RO'] = 'Romania';
$string['RU'] = 'Venj';
$string['RW'] = 'Ruanda';
$string['SA'] = 'Saudi-Arabia';
$string['SB'] = 'Salomonsaaret';
$string['SC'] = 'Seychellit';
$string['SD'] = 'Sudan';
$string['SE'] = 'Ruotsi';
$string['SG'] = 'Singapore';
$string['SH'] = 'St. Helena';
$string['SI'] = 'Slovenia';
$string['SJ'] = 'Huippuvuoret ja Jan Mayen';
$string['SK'] = 'Slovakia';
$string['SL'] = 'Sierra Leone';
$string['SM'] = 'San Marino';
$string['SN'] = 'Senegal';
$string['SO'] = 'Somalia';
$string['SR'] = 'Surinam';
$string['ST'] = 'Sao Tome ja Principe';
$string['SV'] = 'El Salvador';
$string['SY'] = 'Syyria';
$string['SZ'] = 'Swazimaa';
$string['TD'] = 'Tshad';
$string['TG'] = 'Togo';
$string['TH'] = 'Thaimaa';
$string['TJ'] = 'Tadzhikistan';
$string['TM'] = 'Turkmenistan';
$string['TN'] = 'Tunisia';
$string['TO'] = 'Tonga';
$string['TP'] = 'It-Timor';
$string['TR'] = 'Turkki';
$string['TT'] = 'Trinidad ja Tobago';
$string['TV'] = 'Tuvalu';
$string['TW'] = 'Taiwan';
$string['TZ'] = 'Tansania';
$string['UA'] = 'Ukraina';
$string['UG'] = 'Uganda';
$string['US'] = 'Yhdysvallat';
$string['UY'] = 'Uruguay';
$string['UZ'] = 'Uzbekistan';
$string['VA'] = 'Vatikaani';
$string['VE'] = 'Venezuela';
$string['VN'] = 'Vietnam';
$string['VU'] = 'Vanuatu';
$string['WA'] = 'Wales';
$string['WS'] = 'Samoa';
$string['YE'] = 'Jemen';
$string['ZA'] = 'Etel-Afrikka';
$string['ZM'] = 'Zambia';
$string['ZR'] = 'Zaire';
$string['ZW'] = 'Zimbabwe';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/fi/countries.php <==
<?PHP // $Id$ 
      // countries.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004101900)


$string['AD'] = 'Andorra';
$string['AE'] = 'Yhdistyneet arabi emiirikunnat';
$string['AF'] = 'Afganistan';
$string['AG'] = 'Antigua ja Barbuda';
$string['AI'] = 'Angola';
$string['AL'] = 'Albania';
$string['AM'] = 'Armenia';
$string['AN'] = 'Alankomaiden Antillit';
$string['AO'] = 'Angola';
$string['AQ'] = 'Antarktis';
$string['AR'] = 'Argentiina';
$string['AS'] = 'Amerikan Samoa';
$string['AT'] = 'Itvalta';
$string['AU'] = 'Australia';
$string['AW'] = 'Aruba';
$string['AZ'] = 'Azerbaidzan';
$string['BA'] = 'Bosnia-Herzegovina';
$string['BB'] = 'Barbados';
$string['BD'] = 'Bangladesh';
$string['BE'] = 'Belgia';
$string['BF'] = 'Burkina Faso';
$string['BG'] = 'Bulgaria';
$string['BH'] = 'Bahrain';
$string['BI'] = 'Burundi';
$string['BJ'] = 'Benin';
$string['BM'] = 'Bermuda';
$string['BN'] = 'Brunei';
$string['BO'] = 'Bolivia';
$string['BR'] = 'Brasilia';
$string['BS'] = 'Bahamasaaret';
$string['BT'] = 'Bhutan';
$string['BV'] = 'Bouvet\'n saari ';
$string['BW'] = 'Botswana';
$string['BY'] = 'Valko-Venj';
$string['BZ'] = 'Belize';
$string['CA'] = 'Kanada';
$string['CC'] = 'Kookos-Saaret';
$string['CF'] = 'Keski-Afrikan tasavalta';
$string['CG'] = 'Kongo';
$string['CH'] = 'Sveitsi';
$string['CI'] = 'Norsunluurannikko';
$string['CK'] = 'Cookinsaaret';
$string['CL'] = 'Chile';
$string['CM'] = 'Kamerun';
$string['CN'] = 'Kiina';
$string['CO'] = 'Kolumbia';
$string['CR'] = 'Costa Rica';
$string['CS'] = 'Serbia ja Montenegro';
$string['CU'] = 'Kuuba';
$string['CV'] = 'Cap Verde';
$string['CX'] = 'Joulusaaret';
$string['CY'] = 'Kypros';
$string['CZ'] = 'Tsekki';
$string['DE'] = 'Saksa';
$string['DJ'] = 'Djibouti';
$string['DK'] = 'Tanska';
$string['DM'] = 'Dominica';
$string['DO'] = 'Dominikaaninen tasavalta';
$string['DZ'] = 'Algeria';
$string['EC'] = 'Ecuador';
$string['EE'] = 'Viro';
$string['EG'] = 'Egypti';
$string['EH'] = 'Lnsi-Sahara';
$string['ER'] = 'Eritrea';
$string['ES'] = 'Espanja';
$string['ET'] = 'Etiopia';
$string['FI'] = 'Suomi';
$string['FJ'] = 'Fiji';
$string['FK'] = 'Falkland-saaret';
$string['FM'] = 'Micronesian yhdistyneet kansakunnat';
$string['FO'] = 'Frsaaret';
$string['FR'] = 'Ranska';
$string['FX'] = 'Ranska; Metropolitan';
$string['GA'] = 'Gabon';
$string['GB'] = 'Iso-Britannia';
$string['GD'] = 'Grenada';
$string['GE'] = 'Georgia';
$string['GF'] = 'Ranskan Guayana';
$string['GH'] = 'Ghana';
$string['GI'] = 'Gibraltar';
$string['GL'] = 'Grnlanti';
$string['GM'] = 'Gambia';
$string['GN'] = 'Guinea';
$string['GP'] = 'Guadeloupe';
$string['GQ'] = 'Pivntasaajan Guinea';
$string['GR'] = 'Kreikka';
$string['GT'] = 'Guatemala';
$string['GU'] = 'Guam';
$string['GW'] = 'Guinea-Bissau';
$string['GY'] = 'Guayana';
$string['HK'] = 'Hong Kong';
$string['HM'] = 'Heard ja Mc Donald saaret';
$string['HN'] = 'Honduras';
$string['HR'] = 'Kroatia';
$string['HT'] = 'Haiti';
$string['HU'] = 'Unkari';
$string['ID'] = 'Indonesia';
$string['IE'] = 'Irlanti';
$string['IL'] = 'Israel';
$string['IN'] = 'Intia';
$string['IO'] = 'Brittilinen intian valtameren territorio ';
$string['IQ'] = 'Irak';
$string['IR'] = 'Iran';
$string['IS'] = 'Islanti';
$string['IT'] = 'Italia';
$string['JM'] = 'Jamaika';
$string['JO'] = 'Jordania';
$string['JP'] = 'Japani';
$string['KE'] = 'Kenia';
$string['KG'] = 'Kirgistan';
$string['KH'] = 'Kambodsa';
$string['KI'] = 'Kiribati';
$string['KM'] = 'Komorit';
$string['KN'] = 'Saint Kitts ja Nevis ';
$string['KO'] = 'Kosovo';
$string['KP'] = 'Pohjois-Korea';
$string['KR'] = 'Etel-Korea';
$string['KW'] = 'Kuwait';
$string['KY'] = 'Caymansaaret';
$string['KZ'] = 'Kazakstan';
$string['LB'] = 'Libanon';
$string['LC'] = 'Saint Lucia';
$string['LI'] = 'Liechtenstein';
$string['LK'] = 'Sri Lanka';
$string['LR'] = 'Liberia';
$string['LS'] = 'Lesoto';
$string['LT'] = 'Liettua';
$string['LU'] = 'Luxemburg';
$string['LV'] = 'Latvia';
$string['LY'] = 'Libya';
$string['MA'] = 'Marokko';
$string['MC'] = 'Monaco';
$string['MD'] = 'Moldova';
$string['MG'] = 'Madagaskar';
$string['MH'] = 'Marshalsaaret';
$string['MK'] = 'Makedonia';
$string['ML'] = 'Mali';
$string['MM'] = 'Myanmar';
$string['MN'] = 'Mongolia';
$string['MO'] = 'Macao';
$string['MP'] = 'Pohjois-Mariaanit';
$string['MQ'] = 'Martinique';
$string['MR'] = 'Mauritania';
$string['MS'] = 'Montserrat';
$string['MT'] = 'Malta';
$string['MU'] = 'Mauritius';
$string['MV'] = 'Malediivit';
$string['MW'] = 'Malawi';
$string['MX'] = 'Meksiko';
$string['MY'] = 'Malesia';
$string['MZ'] = 'Mosambik';
$string['NA'] = 'Namibia';
$string['NC'] = 'Uusi-Kaledonia';
$string['NE'] = 'Niger';
$string['NF'] = 'Norfolkinsaari';
$string['NG'] = 'Nigeria';
$string['NI'] = 'Nikaragua';
$string['NL'] = 'Alankomaat';
$string['NO'] = 'Norja';
$string['NP'] = 'Nepal';
$string['NR'] = 'Nauru';
$string['NU'] = 'Niue';
$string['NZ'] = 'Uusi-Seelanti';
$string['OM'] = 'Oman';
$string['PA'] = 'Panama';
$string['PE'] = 'Peru';
$string['PF'] = 'Ranskan Polynesia';
$string['PG'] = 'Papua Uusi-Guinea';
$string['PH'] = 'Filippiinit';
$string['PK'] = 'Pakistan';
$string['PL'] = 'Puola';
$string['PM'] = 'St. Pierre ja Miquelon ';
$string['PN'] = 'Pitcairn';
$string['PR'] = 'Puerto Rico';
$string['PS'] = 'Palestiina';
$string['PT'] = 'Portugali';
$string['PW'] = 'Palau';
$string['PY'] = 'Paraguay';
$string['QA'] = 'Qatar';
$string['RE'] = 'Reunion';
$string['RO'] = 'Romania';
$string['RU'] = 'Venj';
$string['RW'] = 'Ruanda';
$string['SA'] = 'Saudi-Arabia';
$string['SB'] = 'Salomonsaaret';
$string['SC'] = 'Seychellit';
$string['SD'] = 'Sudan';
$string['SE'] = 'Ruotsi';
$string['SG'] = 'Singapore';
$string['SH'] = 'St. Helena';
$string['SI'] = 'Slovenia';
$string['SJ'] = 'Huippuvuoret ja Jan Mayen';
$string['SK'] = 'Slovakia';
$string['SL'] = 'Sierra Leone';
$string['SM'] = 'San Marino';
$string['SN'] = 'Senegal';
$string['SO'] = 'Somalia';
$string['SR'] = 'Surinam';
$string['ST'] = 'Sao Tome ja Principe';
$string['SV'] = 'El Salvador';
$string['SY'] = 'Syyria';
$string['SZ'] = 'Swazimaa';
$string['TC'] = 'Turks- ja Caicossaaret ';
$string['TD'] = 'Tshad';
$string['TF'] = 'Ranskan eteliset territoriot ';
$string['TG'] = 'Togo';
$string['TH'] = 'Thaimaa';
$string['TJ'] = 'Tadzhikistan';
$string['TK'] = 'Tokelau';
$string['TM'] = 'Turkmenistan';
$string['TN'] = 'Tunisia';
$string['TO'] = 'Tonga';
$string['TP'] = 'It-Timor';
$string['TR'] = 'Turkki';
$string['TT'] = 'Trinidad ja Tobago';
$string['TV'] = 'Tuvalu';
$string['TW'] = 'Taiwan';
$string['TZ'] = 'Tansania';
$string['UA'] = 'Ukraina';
$string['UG'] = 'Uganda';
$string['US'] = 'Yhdysvallat';
$string['UY'] = 'Uruguay';
$string['UZ'] = 'Uzbekistan';
$string['VA'] = 'Vatikaani';
$string['VC'] = 'Saint Vincent ja Grenadiinit';
$string['VE'] = 'Venezuela';
$string['VG'] = 'Brittiliset neitsytsaaret';
$string['VI'] = 'Yhdysvaltain Neitsytsaaret';
$string['VN'] = 'Vietnam';
$string['VU'] = 'Vanuatu';
$string['WA'] = 'Wales';
$string['WF'] = 'Wallis- ja Futunasaaret ';
$string['WS'] = 'Samoa';
$string['YE'] = 'Jemen';
$string['YT'] = 'Mayotte';
$string['ZA'] = 'Etel-Afrikka';
$string['ZM'] = 'Zambia';
$string['ZR'] = 'Zaire';
$string['ZW'] = 'Zimbabwe';
$string['thischarset'] = 'iso-8859-1';
$string['thisdirection'] = 'ltr';
$string['thislanguage'] = 'Suomi';

?>
